/*  $Id: DefaultSaxParser.java 1329 2012-08-25 08:33:05Z sdevaux $
 *
 * Tabs = 4 chars
 * copyright (C) 2007 Sebastien Devaux
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA
 *
 *              Sebastien Devaux <sebastien.devaux@laposte.net>
 */
package net.eduvax.xml;


import org.xml.sax.Attributes; 
import java.io.FileNotFoundException;
import java.io.InputStream;
import java.io.IOException;
import java.util.Date;
import org.xml.sax.SAXException;
import org.xml.sax.helpers.DefaultHandler;

/**
 * Default all in one parser-handler.
 * @version $Id: DefaultSaxParser.java 1329 2012-08-25 08:33:05Z sdevaux $
 * @author Sebastien Devaux	
 */
public abstract class DefaultSaxParser extends DefaultHandler {
	/**
	 * checks element name and qname
	 * @param candidate tag to check
	 * @param name name
	 * @param qName qualified name
	 * @return true when candidate equals name or qName.
	 */ 
	public static boolean checkTag(String candidate,String name,
													String qName) {
		return candidate.equals(name) || candidate.equals(qName);
	}
	/**
	 * Parse input stream
	 * @param input xml source stream
	 */ 
	public void parse(InputStream input) throws SAXException, IOException {
		SaxParser sp=SaxParser.getInputStreamParser(input,this);
		sp.parse();
	}
	/**
	 * parse file
	 * @param filePath path of file to read
	 */ 
	public void parse(String filePath) throws FileNotFoundException, IOException, SAXException {
		SaxParser sp=SaxParser.getFileParser(filePath,this);
		sp.parse();
	}

    public Date getDateAttribute(Attributes atts, String name) {
        String dateStr=atts.getValue(name);
        if (dateStr!=null) {
            return XML.getDate(dateStr);
        }
        else {
            return null;
        }
    }
}


